@@ -26,8 +26,7 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s zrušil(a) sdílení složky „%2$s“ vám",
     "Someone unshared folder \"%s\" with you" : "Někdo zrušil sdílení složky „%s“ vám",
     "No file provided for import" : "Nezadali jste soubor k importu",
-    "Unsupported file type for import" : "Nepodporovaný typ souboru pro import",
-    "Bookmarks Backups" : "Zálohy záložek",
+    "Failed to upload file" : "Nepodařilo se nahrát soubor",
     "Bookmarks shared by %s" : "Záložky, které sdílí %s",
     "Frequent bookmarks" : "Často využívané záložky",
     "Recent bookmarks" : "Nedávné záložky",
@@ -38,7 +37,7 @@ OC.L10N.register(
     "Bookmark updated" : "Záložka aktualizována",
     "Create bookmark" : "Vytvořit záložku",
     "Takes a link and adds it to your collection of bookmarks." : "Vezme odkaz a přidá ho do vaší sbírky záložek.",
-    "A Bookmark manager for Nextcloud" : "Správce záložek pro Nextcloud",
+    "Bookmarks Backups" : "Zálohy záložek",
     "Enter new title" : "Zadejte nový titulek",
     "Select bookmark" : "Vybrat záložku",
     "Details" : "Podrobnosti",
@@ -46,7 +45,6 @@ OC.L10N.register(
     "Copy link" : "Zkopírovat odkaz",
     "Move" : "Přesunout",
     "Add to folders" : "Přidat složek",
-    "Delete" : "Smazat",
     "Do you really want to delete this bookmark?" : "Opravdu chcete tuto záložku smazat?",
     "Link copied to clipboard" : "Odkaz zkopírován do schánky",
     "Content pending" : "Obsah čeká na vyřízení",
@@ -65,8 +63,6 @@ OC.L10N.register(
     "Cancel selection" : "Zrušit výběr",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Vybráno {folders} složek a {bookmarks} záložek",
     "Do you really want to delete these items?" : "Opravdu chcete tyto položky smazat?",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Vybrána %n záložka","Vybrány %n záložky","Vybráno %n záložek","Vybrány %n záložky"],
-    "_Selected %n folder_::_Selected %n folders_" : ["Vybrat %n složku","Vybrat %n složky","Vybrat %n složek","Vybrat %n složky"],
     "Go back" : "Jít zpět",
     "Share folder" : "Sdílet složku",
     "Select one or more tags" : "Vyberte jeden nebo více štítků",
@@ -78,6 +74,7 @@ OC.L10N.register(
     "Copy RSS Feed of current view" : "Zkopírovat RSS kanál stávajícího pohledu",
     "The RSS feed requires authentication with your Nextcloud credentials" : "RSS kanál vyžaduje ověření se prostřednictvím vašich přihlašovacích údajů do Nextcloud",
     "Search" : "Hledat",
+    "Empty trash bin" : "Vyprázdnit koš",
     "Sort by created date" : "Seřadit podle data vytvoření",
     "Sort by last modified" : "Seřadit podle okamžiku poslední úpravy",
     "Sort by title" : "Seřadit podle nadpisu",
@@ -85,13 +82,10 @@ OC.L10N.register(
     "Sort by manual order" : "Seřadit ručně",
     "Sort by URL" : "Seřadit podle URL",
     "RSS feed copied" : "RSS kanál zkopírován",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Přidává se %n záložka do nové složky","Přidávají se %n záložky do nové složky","Přidává se %n záložek do nové složky","Přidávají se %n záložky do nové složky"],
     "Enter a link" : "Zadejte odkaz",
     "Enter a title" : "Zadejte titulek",
     "No bookmarks found" : "Nenalezeny žádné záložky",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} složek a {bookmarks} záložek",
-    "_%n bookmark_::_%n bookmarks_" : ["%n záložka","%n záložky","%n záložek","%n záložky"],
-    "_%n folder_::_%n folders_" : ["%n složka","%n složky","%n složek","%n složky"],
     "Welcome to Bookmarks" : "Vítejte v Záložkách",
     "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Tato aplikace umožňuje spravovat si odkazy na svá oblíbená místa na webu. Uspořádávejte si své záložky do složek, opatřete je štítky a sdílejte je s ostatními! Aplikace pravidelně kontroluje, zda jsou odkazy stále ještě funkční a zobrazí ty, které nejsou. Pokud přidáte odkaz na soubor na webu, soubor bude automaticky stažen do Nextcloud Soubory. Pomocí aplikace Záložky je také možné naimportovat záložky exportované z ostatních služeb nebo přímo synchronizovat záložky ze všech vašich prohlížečů.",
     "Add a bookmark" : "Přidat do záložek",
@@ -102,8 +96,6 @@ OC.L10N.register(
     "Shared by {user}" : "Sdílí {user}",
     "Rename folder" : "Přejmenovat složku",
     "Move folder" : "Přesunout složku",
-    "Delete folder" : "Smazat složku",
-    "Do you really want to delete this folder?" : "Opravdu chcete tuto složku smazat?",
     "Choose folder" : "Zvolte složku",
     "Submit" : "Odeslat",
     "Cancel" : "Storno",
@@ -112,9 +104,6 @@ OC.L10N.register(
     "Importing bookmarks" : "Importování záložek",
     "Moving selection" : "Přesouvání vybraných",
     "Adding selection to folders" : "Přidává se výběr do složek",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Přesouvá se %n složka a nějaké záložky","Přesouvají se %n složky a nějaké záložky","Přesouvá se %n složek a nějaké záložky","Přesouvají se %n složky a nějaké záložky"],
-    "_Moving %n folder_::_Moving %n folders_" : ["Přesouvá se %n složka","Přesouvají se %n složky","Přesouvá se %n složek","Přesouvají se %n složky"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Přesouvá se %n záložka","Přesouvají se %n záložky","Přesouvá se %n záložek","Přesouvají se %n záložky"],
     "All bookmarks" : "Všechny záložky",
     "Recent" : "Nedávné",
     "Shared with you" : "Nasdíleno vám",
@@ -123,6 +112,7 @@ OC.L10N.register(
     "Broken links" : "Nefunkční odkazy",
     "New tag" : "Nový štítek",
     "Search tags" : "Hledat štítky",
+    "Delete" : "Smazat",
     "Untagged" : "Neoštítkováno",
     "{used} bookmarks of {available} available" : "{used} záložek z {available} k dispozici",
     "No bookmarked files" : "Žádné záložky na soubory",
@@ -132,21 +122,21 @@ OC.L10N.register(
     "No duplicated bookmarks" : "Žádné duplicitní záložky",
     "No bookmarks here" : "Nejsou zde žádné záložky",
     "Add bookmarks manually or import bookmarks from a HTML file." : "Záložky přidávejte ručně nebo je naimportujte z HTML souboru.",
-    "Import" : "Importovat",
-    "Export" : "Export",
-    "Archive path" : "Popis umístění archivu",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "Zadejte popis umístění složky ve svých Souborech, ve které by měly být uchovávány soubory, umístěné do záložek",
-    "Backups" : "Zálohy",
-    "Enable bookmarks backups" : "Zapnout zálohování záložek",
+    "Auto-Backup" : "Automatická záloha",
+    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Aplikace Záložky může provádět každodenní automatickou zálohu vašich záložek a bránit tak ztrátě dat při jejich synchronizaci napříč zařízeními.",
+    "Enable backups" : "Zapnout zálohování",
     "Enter the path of a folder in your Files where backups will be stored." : "Zadejte popis umístění složky ve svých Souborech, do kterého ukládat zálohy.",
     "Client apps" : "Klientské aplikace",
     "Also check out the collection of client apps that integrate with this app: " : "Také se podívejte na sadu klientských aplikací, které napojují na tuto aplikaci:",
-    "Install web app on device" : "Nainstalovat webovou aplikaci na zařízení",
+    "Install web app" : "Nainstalovat webovou aplikaci",
     "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Tuto aplikaci můžete nainstalovat na domovskou obrazovku svého zařízení a získat tak rychlý přístup ke svým záložkám na telefonu. Pokud by se vám to nelíbilo, můžete aplikaci z domovské obrazovky zase snadno odstranit.",
     "Install on home screen" : "Nainstalovat na domovskou obrazovku",
     "Bookmarklet" : "Miniaplikace v záložce (bookmarklet)",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Toto přetáhněte do záložek svého prohlížeče a kliknutím přidejte stránku do záložek.",
     "Add to {instanceName}" : "Přidat do {instanceName}",
+    "Need help?" : "Potřebujete nápovědu?",
+    "Archive path" : "Popis umístění archivu",
     "Backup path" : "Popis umístění záloh",
     "Please select \"Add to home screen\" in your browser menu" : "Z nabídky webového prohlížeče vyberte „Přidat na domovskou obrazovku“",
     "Title" : "Nadpis",
@@ -158,7 +148,7 @@ OC.L10N.register(
     "Notes" : "Poznámky",
     "Notes for this bookmark …" : "Poznámky k této záložce…",
     "Archived file" : "Zaarchivovaný soubor",
-    "Download file" : "Stáhnout soubor",
+    "Download file" : "Stáhnout si soubor",
     "Open file location" : "Otevřít umístění souboru",
     "Created {time} ago" : "Vytvořeno před {time}",
     "Created on {date}" : "Vytvořeno {date}",
@@ -177,23 +167,20 @@ OC.L10N.register(
     "Remove share" : "Odebrat sdílení",
     "Link copied" : "Odkaz zkopírován",
     "Privacy" : "Soukromí",
-    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Záložky se budou snažit přistoupit k webovým stránkám, které jste přidali aby automaticky doplnily informace o nich.",
     "Enable accessing and collecting information from the web pages you add" : "Zapnout přístup a shromažďování informací z webových stránek, které přidáte",
     "Performance" : "Výkonnost",
     "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "U instalace s mnoha uživateli může být užitečné omezit počet záložek pro jednotlivé účty.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Nejvyšší umožněný počet záložek v jednotlivých účtech (pro bez omezení 0, výchozí je právě bez limitu)",
     "Previews" : "Náhledy",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Pro zobrazování skutečných snímků obrazovky webů, které máte v záložkách, Záložky mohou použít pro vytváření náhledů služby třetích stran.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Je možné se buď bezplatně zaregistrovat na screeenly.com nebo si vytvořit vlastní server.",
     "Screeenly API URL" : "URL adresa aplikačního program. rozhraní (API) služby Screenly",
     "Screeenly API key" : "Klíč k aplikačnímu program. rozhraní (API) služby Screenly",
-    "Webshot" : "Webshot",
-    "Webshot API URL" : "URL adresa API rozhraní služby Webshot",
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "Klíč k API rozhraní služby ScreenshotMachine",
+    "Webshot" : "Webshot",
+    "Webshot API URL" : "URL adresa API rozhraní služby Webshot",
     "Pageres CLI" : "Pageres CLI",
-    "Simply install the Pageres CLI on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Stačí jen nainstalovat na server Pageres CLI a aplikace Záložky si ji najde. I tak je možné přidat další proměnné prostředí, které předat pageres, např. jak je naznačeno ve výplňovém textu:",
     "Pageres ENV variables" : "Proměnné prostředí pro pageres",
     "Failed to save settings" : "Nastavení se nepodařilo uložit",
     "Failed to load settings" : "Nepodařilo se načíst nastavení",
@@ -204,9 +191,8 @@ OC.L10N.register(
     "Root Folder" : "Kořenová složka",
     "Save" : "Uložit",
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Přístup k síti je ve výchozím stavu vypnut. Pokud chcete umožnit stahování náhledů a ikon webů, jděte do nastavení správy aplikace Záložky a zapněte ho tam.",
-    "What's new in Bookmarks?" : "Co je v Záložkách nového?",
+    "What's new?" : "Co je nového?",
     "What" : "Co",
-    "Link to a bookmark folder" : "Propojit se složkou záložek",
     "Failed to count unavailable bookmarks" : "Nepodařilo se spočítat nedostupné záložky",
     "Failed to count archived bookmarks" : "Nepodařilo se spočítat archivované záložky",
     "Failed to count duplicated bookmarks" : "Nepodařilo se spočítat duplicitní záložky",
@@ -223,7 +209,6 @@ OC.L10N.register(
     "Failed to delete folder" : "Složku se nepodařilo smazat",
     "Failed to create folder" : "Složku se nepodařilo vytvořit",
     "Failed to fetch bookmarks." : "Záložky se nepodařilo stáhnout.",
-    "Failed to change setting" : "Nepodařilo se změnit nastavení",
     "Failed to load setting {key}" : "Nepodařilo se načíst nastavení {key}",
     "Failed to update share {shareId}" : "Nepodařilo se aktualizovat sdílení {shareId}",
     "Failed to delete share {shareId}" : "Nepodařilo se smazat sdílení {shareId}",
